==> heptapod-rails-0.26.0.tar.gz: heptapod-rails-0.26.0/qa/qa/specs/features/browser_ui/3_create/wiki/project_based_list_spec.rb <==
# frozen_string_literal: true

module QA
  RSpec.describe 'Create' do
    context 'Wiki' do
      let(:small_number_of_pages) { 5 }
      let(:large_number_of_pages) { 15 }
      let(:random_page) { "bulk_#{rand(0..4)}" }

      let(:small_wiki) { create_wiki_pages small_number_of_pages }
      let(:large_wiki) { create_wiki_pages large_number_of_pages }

      before do
        Flow::Login.sign_in
      end

      context 'Sidebar' do
        it 'has all expected links that work', testcase: 'https://gitlab.com/gitlab-org/quality/testcases/-/issues/903' do
          small_wiki.visit!

          small_number_of_pages.times do |index|
            Page::Project::Wiki::Show.perform do |list|
              expect(list).to have_page_listed "bulk_#{index}"
            end
          end

          Page::Project::Wiki::Show.perform do |list|
            list.click_page_link random_page
          end

          Page::Project::Wiki::Show.perform do |wiki|
            expect(wiki).to have_title random_page
          end
        end
      end

      context 'Page List' do
        it 'has all expected links that work', testcase: 'https://gitlab.com/gitlab-org/quality/testcases/-/issues/902' do
          large_wiki.visit!

          Page::Project::Wiki::Show.perform(&:click_view_all_pages)

          large_number_of_pages.times do |index|
            Page::Project::Wiki::List.perform do |list|
              expect(list).to have_page_listed "bulk_#{index}"
            end
          end

          Page::Project::Wiki::List.perform do |list|
            list.click_page_link random_page
          end

          Page::Project::Wiki::Show.perform do |wiki|
            expect(wiki).to have_title random_page
          end
        end
      end

      private

      def create_wiki_pages(no_of_pages)
        wiki = Resource::Wiki::ProjectPage.fabricate_via_api!
        no_of_pages.times do |index|
          Resource::Wiki::ProjectPage.fabricate_via_api! do |page|
            page.title = "bulk_#{index}"
            page.project = wiki.project
          end
        end
        wiki
      end
    end
  end
end

==> heptapod-rails-0.27.4.tar.gz: heptapod-rails-0.27.4/qa/qa/specs/features/browser_ui/3_create/wiki/project_based_list_spec.rb <==
# frozen_string_literal: true

module QA
  RSpec.describe 'Create' do
    context 'Wiki' do
      let(:small_number_of_pages) { 5 }
      let(:large_number_of_pages) { 15 }
      let(:random_page) { "bulk_#{rand(0..4)}" }

      let(:small_wiki) { create_wiki_pages small_number_of_pages }
      let(:large_wiki) { create_wiki_pages large_number_of_pages }

      before do
        Flow::Login.sign_in
      end

      context 'Sidebar' do
        it 'has all expected links that work', testcase: 'https://gitlab.com/gitlab-org/quality/testcases/-/quality/test_cases/1317' do
          small_wiki.visit!

          small_number_of_pages.times do |index|
            Page::Project::Wiki::Show.perform do |list|
              expect(list).to have_page_listed "bulk_#{index}"
            end
          end

          Page::Project::Wiki::Show.perform do |list|
            list.click_page_link random_page
          end

          Page::Project::Wiki::Show.perform do |wiki|
            expect(wiki).to have_title random_page
          end
        end
      end

      context 'Page List' do
        it 'has all expected links that work', testcase: 'https://gitlab.com/gitlab-org/quality/testcases/-/quality/test_cases/1318' do
          large_wiki.visit!

          Page::Project::Wiki::Show.perform(&:click_view_all_pages)

          large_number_of_pages.times do |index|
            Page::Project::Wiki::List.perform do |list|
              expect(list).to have_page_listed "bulk_#{index}"
            end
          end

          Page::Project::Wiki::List.perform do |list|
            list.click_page_link random_page
          end

          Page::Project::Wiki::Show.perform do |wiki|
            expect(wiki).to have_title random_page
          end
        end
      end

      private

      def create_wiki_pages(no_of_pages)
        wiki = Resource::Wiki::ProjectPage.fabricate_via_api!
        no_of_pages.times do |index|
          Resource::Wiki::ProjectPage.fabricate_via_api! do |page|
            page.title = "bulk_#{index}"
            page.project = wiki.project
          end
        end
        wiki
      end
    end
  end
end
